@@ -281,7 +281,7 @@ ChimeraCheckCommand::ChimeraCheckCommand(string option)  {
 
 			string temp = validParameter.validFile(parameters, "processors", false);	if (temp == "not found"){	temp = m->getProcessors();	}
 			m->setProcessors(temp);
-			convert(temp, processors);
+			m->mothurConvert(temp, processors);
 			
 			temp = validParameter.validFile(parameters, "save", false);			if (temp == "not found"){	temp = "f";				}
 			save = m->isTrue(temp); 
@@ -306,14 +306,14 @@ ChimeraCheckCommand::ChimeraCheckCommand(string option)  {
 			
 			
 			temp = validParameter.validFile(parameters, "ksize", false);			if (temp == "not found") { temp = "7"; }
-			convert(temp, ksize);
+			m->mothurConvert(temp, ksize);
 			
 			temp = validParameter.validFile(parameters, "svg", false);				if (temp == "not found") { temp = "F"; }
 			svg = m->isTrue(temp);
 			if (nameFileNames.size() != 0) { svg = true; }
 			
 			temp = validParameter.validFile(parameters, "increment", false);		if (temp == "not found") { temp = "10"; }
-			convert(temp, increment);			
+			m->mothurConvert(temp, increment);			
 		}
 	}
 	catch(exception& e) {
@@ -424,14 +424,16 @@ int ChimeraCheckCommand::execute(){
 				MPI_Barrier(MPI_COMM_WORLD); //make everyone wait - just in case
 		#else
 			
-			vector<unsigned long long> positions = m->divideFile(fastaFileNames[i], processors);
-				
-			for (int s = 0; s < (positions.size()-1); s++) {
-				lines.push_back(new linePair(positions[s], positions[(s+1)]));
-			}	
+			
 			
 			//break up file
 			#if defined (__APPLE__) || (__MACH__) || (linux) || (__linux)
+				vector<unsigned long long> positions = m->divideFile(fastaFileNames[i], processors);
+			
+				for (int s = 0; s < (positions.size()-1); s++) {
+					lines.push_back(new linePair(positions[s], positions[(s+1)]));
+				}	
+			
 				if(processors == 1){
 					numSeqs = driver(lines[0], outputFileName, fastaFileNames[i]);
 					
@@ -459,6 +461,7 @@ int ChimeraCheckCommand::execute(){
 				}
 
 			#else
+				lines.push_back(new linePair(0, 1000));
 				numSeqs = driver(lines[0], outputFileName, fastaFileNames[i]);
 				
 				if (m->control_pressed) { for (int j = 0; j < lines.size(); j++) {  delete lines[j];  }  lines.clear(); for (int j = 0; j < outputNames.size(); j++) {	m->mothurRemove(outputNames[j]);	} outputTypes.clear(); delete chimera; return 0; }
