@@ -225,13 +225,13 @@ ChimeraPintailCommand::ChimeraPintailCommand(string option)  {
 			
 			temp = validParameter.validFile(parameters, "processors", false);	if (temp == "not found"){	temp = m->getProcessors();	}
 			m->setProcessors(temp);
-			convert(temp, processors);
+			m->mothurConvert(temp, processors);
 			
 			temp = validParameter.validFile(parameters, "window", false);			if (temp == "not found") { temp = "0"; }
-			convert(temp, window);
+			m->mothurConvert(temp, window);
 			
 			temp = validParameter.validFile(parameters, "increment", false);		if (temp == "not found") { temp = "25"; }
-			convert(temp, increment);
+			m->mothurConvert(temp, increment);
 			
 			temp = validParameter.validFile(parameters, "save", false);			if (temp == "not found"){	temp = "f";				}
 			save = m->isTrue(temp); 
@@ -486,14 +486,15 @@ int ChimeraPintailCommand::execute(){
 				MPI_File_close(&outMPIAccnos);
 				MPI_Barrier(MPI_COMM_WORLD); //make everyone wait - just in case
 		#else
-			vector<unsigned long long> positions = m->divideFile(fastaFileNames[s], processors);
-				
-			for (int i = 0; i < (positions.size()-1); i++) {
-				lines.push_back(new linePair(positions[i], positions[(i+1)]));
-			}	
-			
+						
 			//break up file
 			#if defined (__APPLE__) || (__MACH__) || (linux) || (__linux)
+				vector<unsigned long long> positions = m->divideFile(fastaFileNames[s], processors);
+			
+				for (int i = 0; i < (positions.size()-1); i++) {
+					lines.push_back(new linePair(positions[i], positions[(i+1)]));
+				}	
+			
 				if(processors == 1){
 		
 					numSeqs = driver(lines[0], outputFileName, fastaFileNames[s], accnosFileName);
@@ -531,6 +532,7 @@ int ChimeraPintailCommand::execute(){
 				}
 
 			#else
+				lines.push_back(new linePair(0, 1000));
 				numSeqs = driver(lines[0], outputFileName, fastaFileNames[s], accnosFileName);
 				
 				if (m->control_pressed) { outputTypes.clear(); m->mothurRemove(outputFileName); m->mothurRemove(accnosFileName); for (int j = 0; j < outputNames.size(); j++) {	m->mothurRemove(outputNames[j]);	} for (int i = 0; i < lines.size(); i++) {  delete lines[i];  }  lines.clear(); delete chimera; return 0; }
