@@ -121,7 +121,7 @@ ChopSeqsCommand::ChopSeqsCommand(string option)  {
 			outputDir = validParameter.validFile(parameters, "outputdir", false);		if (outputDir == "not found"){	outputDir = m->hasPath(fastafile);	}
 			
 			string temp = validParameter.validFile(parameters, "numbases", false);	if (temp == "not found") { temp = "0"; } 
-			convert(temp, numbases);   
+			m->mothurConvert(temp, numbases);   
 			
 			temp = validParameter.validFile(parameters, "countgaps", false);	if (temp == "not found") { temp = "f"; } 
 			countGaps = m->isTrue(temp);  
@@ -241,7 +241,7 @@ string ChopSeqsCommand::getChopped(Sequence seq) {
 					}
 					
 					if (stopSpot == 0) { temp = ""; }
-					else {  temp = temp.substr(0, stopSpot);  }
+					else {  temp = temp.substr(0, stopSpot+1);  }
 							
 				}else { 
 					if (!Short) { temp = ""; } //sequence too short
@@ -294,7 +294,7 @@ string ChopSeqsCommand::getChopped(Sequence seq) {
 					}
 					
 					if (stopSpot == 0) { temp = ""; }
-					else {  temp = temp.substr(0, stopSpot);  }
+					else {  temp = temp.substr(0, stopSpot+1);  }
 							
 				}else { 
 					if (!Short) { temp = ""; } //sequence too short
@@ -320,7 +320,7 @@ string ChopSeqsCommand::getChopped(Sequence seq) {
 					}
 				
 					if (stopSpot == 0) { temp = ""; }
-					else {  temp = temp.substr(stopSpot+1);  }
+					else {  temp = temp.substr(stopSpot);  }
 				}else { 
 					if (!Short) { temp = ""; } //sequence too short
 				}
