@@ -206,7 +206,7 @@ ClassifyOtuCommand::ClassifyOtuCommand(string option)  {
 			if ((basis != "otu") && (basis != "sequence")) { m->mothurOut("Invalid option for basis. basis options are otu and sequence, using otu."); m->mothurOutEndLine(); }
 			
 			string temp = validParameter.validFile(parameters, "cutoff", false);			if (temp == "not found") { temp = "51"; }
-			convert(temp, cutoff); 
+			m->mothurConvert(temp, cutoff); 
 			
 			temp = validParameter.validFile(parameters, "probs", false);					if (temp == "not found"){	temp = "true";			}
 			probs = m->isTrue(temp);
@@ -368,7 +368,7 @@ int ClassifyOtuCommand::readTaxonomyFile() {
 			m->gobble(in);
 			
 			//are there confidence scores, if so remove them
-			if (tax.find_first_of('(') != -1) {  removeConfidences(tax);	}
+			if (tax.find_first_of('(') != -1) {  m->removeConfidences(tax);	}
 			
 			taxMap[name] = tax;
 			
@@ -550,7 +550,7 @@ int ClassifyOtuCommand::process(ListVector* processList) {
 			out << (i+1) << '\t' << size << '\t' << conTax << endl;
 			
 			string noConfidenceConTax = conTax;
-			removeConfidences(noConfidenceConTax);
+			m->removeConfidences(noConfidenceConTax);
 			
 			//add this bins taxonomy to summary
 			if (basis == "sequence") {
@@ -604,36 +604,6 @@ string ClassifyOtuCommand::addUnclassifieds(string tax, int maxlevel) {
 		exit(1);
 	}
 }
-
-/**************************************************************************************************/
-void ClassifyOtuCommand::removeConfidences(string& tax) {
-	try {
-		
-		string taxon;
-		string newTax = "";
-		
-		while (tax.find_first_of(';') != -1) {
-			//get taxon
-			taxon = tax.substr(0,tax.find_first_of(';'));
-			
-			int pos = taxon.find_first_of('(');
-			if (pos != -1) {
-				taxon = taxon.substr(0, pos); //rip off confidence 
-			}
-			
-			taxon += ";";
-			
-			tax = tax.substr(tax.find_first_of(';')+1, tax.length());
-			newTax += taxon;
-		}
-		
-		tax = newTax;
-	}
-	catch(exception& e) {
-		m->errorOut(e, "ClassifyOtuCommand", "removeConfidences");
-		exit(1);
-	}
-}
 //**********************************************************************************************************************
 
 
