@@ -123,6 +123,9 @@
 #include "countgroupscommand.h"
 #include "clearmemorycommand.h"
 #include "summarytaxcommand.h"
+#include "chimeraperseuscommand.h"
+#include "shhhseqscommand.h"
+#include "summaryqualcommand.h"
 
 /*******************************************************/
 
@@ -201,7 +204,7 @@ CommandFactory::CommandFactory(){
 	commands["pre.cluster"]			= "pre.cluster";
 	commands["pcoa"]				= "pcoa";
 	commands["otu.hierarchy"]		= "otu.hierarchy";
-	commands["set.dir"]				= "set.dir";
+	commands["set.dir"]				= "MPIEnabled";
 	commands["merge.files"]			= "merge.files";
 	commands["parse.list"]			= "parse.list";
 	commands["set.logfile"]			= "set.logfile";
@@ -241,8 +244,8 @@ CommandFactory::CommandFactory(){
 	commands["anosim"]				= "anosim";
 	commands["make.fastq"]			= "make.fastq";
 	commands["merge.groups"]		= "merge.groups";
-	commands["get.current"]			= "get.current";
-	commands["set.current"]			= "set.current";
+	commands["get.current"]			= "MPIEnabled";
+	commands["set.current"]			= "MPIEnabled";
 	commands["get.commandinfo"]		= "get.commandinfo";
 	commands["deunique.tree"]		= "deunique.tree";
 	commands["count.seqs"]			= "count.seqs";
@@ -258,6 +261,7 @@ CommandFactory::CommandFactory(){
 	commands["chimera.check"]		= "MPIEnabled";
 	commands["chimera.slayer"]		= "MPIEnabled";
 	commands["chimera.uchime"]		= "chimera.uchime";
+	commands["chimera.perseus"]		= "chimera.perseus";
 	commands["chimera.pintail"]		= "MPIEnabled";
 	commands["chimera.bellerophon"]	= "MPIEnabled";
 	commands["screen.seqs"]			= "MPIEnabled";
@@ -266,7 +270,9 @@ CommandFactory::CommandFactory(){
 	commands["shhh.flows"]			= "MPIEnabled";
 	commands["sens.spec"]			= "sens.spec";
 	commands["seq.error"]			= "seq.error";
-	commands["seq.error"]			= "summary.tax";
+	commands["summary.tax"]			= "summary.tax";
+	commands["summary.qual"]		= "summary.qual";
+	commands["shhh.seqs"]			= "shhh.seqs";
 	commands["quit"]				= "MPIEnabled"; 
 
 }
@@ -424,6 +430,9 @@ Command* CommandFactory::getCommand(string commandName, string optionString){
 		else if(commandName == "count.groups")			{	command = new CountGroupsCommand(optionString);				}
 		else if(commandName == "clear.memory")			{	command = new ClearMemoryCommand(optionString);				}
 		else if(commandName == "summary.tax")			{	command = new SummaryTaxCommand(optionString);				}
+		else if(commandName == "summary.qual")			{	command = new SummaryQualCommand(optionString);				}
+		else if(commandName == "chimera.perseus")		{	command = new ChimeraPerseusCommand(optionString);			}
+		else if(commandName == "shhh.seqs")				{	command = new ShhhSeqsCommand(optionString);				}
 		else											{	command = new NoCommand(optionString);						}
 
 		return command;
@@ -565,6 +574,9 @@ Command* CommandFactory::getCommand(string commandName, string optionString, str
 		else if(commandName == "count.groups")			{	pipecommand = new CountGroupsCommand(optionString);				}
 		else if(commandName == "clear.memory")			{	pipecommand = new ClearMemoryCommand(optionString);				}
 		else if(commandName == "summary.tax")			{	pipecommand = new SummaryTaxCommand(optionString);				}
+		else if(commandName == "summary.qual")			{	pipecommand = new SummaryQualCommand(optionString);				}
+		else if(commandName == "chimera.perseus")		{	pipecommand = new ChimeraPerseusCommand(optionString);			}
+		else if(commandName == "shhh.seqs")				{	pipecommand = new ShhhSeqsCommand(optionString);				}
 		else											{	pipecommand = new NoCommand(optionString);						}
 
 		return pipecommand;
@@ -694,6 +706,9 @@ Command* CommandFactory::getCommand(string commandName){
 		else if(commandName == "count.groups")			{	shellcommand = new CountGroupsCommand();			}
 		else if(commandName == "clear.memory")			{	shellcommand = new ClearMemoryCommand();			}
 		else if(commandName == "summary.tax")			{	shellcommand = new SummaryTaxCommand();				}
+		else if(commandName == "summary.qual")			{	shellcommand = new SummaryQualCommand();			}
+		else if(commandName == "chimera.perseus")		{	shellcommand = new ChimeraPerseusCommand();			}
+		else if(commandName == "shhh.seqs")				{	shellcommand = new ShhhSeqsCommand();				}
 		else											{	shellcommand = new NoCommand();						}
 
 		return shellcommand;
