@@ -24,6 +24,9 @@ public:
 	string getCommandName()			{ return "consensus.seqs";		}
 	string getCommandCategory()		{ return "Sequence Processing"; }
 	string getHelpString();	
+	string getCitation() { return "http://www.mothur.org/wiki/Consensus.seqs"; }
+	string getDescription()		{ return "create a consensus sequence for each OTU or for a fasta file"; }
+
 	
 	int execute(); 
 	void help() { m->mothurOut(getHelpString()); }	
@@ -37,12 +40,13 @@ private:
 	map<string, string> fastaMap;
 	map<string, string> nameMap;
 	map<string, string> nameFileMap;
+	int cutoff;
 	
 	int readFasta();
 	int readNames();
 	int processList(ListVector*&);
 	string getConsSeq(string, ofstream&, string&, int);
-	char getBase(vector<int>);
+	char getBase(vector<int>, int);
 };
 
 #endif
