@@ -24,7 +24,7 @@
 //custom data structure for threads to use.
 // This is passed by void pointer so it can be any data type
 // that can be passed using a single void pointer (LPVOID).
-typedef struct distanceData {
+struct distanceData {
 	int startLine;
 	int endLine;
 	string dFileName;
