@@ -16,12 +16,12 @@
 //**********************************************************************************************************************
 vector<string> GetGroupsCommand::setParameters(){	
 	try {
-		CommandParameter pfasta("fasta", "InputTypes", "", "", "none", "FNGLT", "none",false,false); parameters.push_back(pfasta);
-		CommandParameter pshared("shared", "InputTypes", "", "", "none", "FNGLT-sharedGroup", "none",false,false); parameters.push_back(pshared);
-		CommandParameter pname("name", "InputTypes", "", "", "none", "FNGLT", "none",false,false); parameters.push_back(pname);
-		CommandParameter pgroup("group", "InputTypes", "", "", "none", "FNGLT-sharedGroup", "none",false,false); parameters.push_back(pgroup);
-		CommandParameter plist("list", "InputTypes", "", "", "none", "FNGLT", "none",false,false); parameters.push_back(plist);
-		CommandParameter ptaxonomy("taxonomy", "InputTypes", "", "", "none", "FNGLT", "none",false,false); parameters.push_back(ptaxonomy);
+		CommandParameter pfasta("fasta", "InputTypes", "", "", "none", "none", "FNGLT",false,false); parameters.push_back(pfasta);
+		CommandParameter pshared("shared", "InputTypes", "", "", "none", "sharedGroup", "none",false,false); parameters.push_back(pshared);
+		CommandParameter pname("name", "InputTypes", "", "", "none", "none", "none",false,false); parameters.push_back(pname);
+		CommandParameter pgroup("group", "InputTypes", "", "", "none", "sharedGroup", "FNGLT",false,false); parameters.push_back(pgroup);
+		CommandParameter plist("list", "InputTypes", "", "", "none", "none", "FNGLT",false,false); parameters.push_back(plist);
+		CommandParameter ptaxonomy("taxonomy", "InputTypes", "", "", "none", "none", "FNGLT",false,false); parameters.push_back(ptaxonomy);
 		CommandParameter paccnos("accnos", "InputTypes", "", "", "none", "none", "none",false,false); parameters.push_back(paccnos);
 		CommandParameter pgroups("groups", "String", "", "", "", "", "",false,false); parameters.push_back(pgroups);
 		CommandParameter pinputdir("inputdir", "String", "", "", "", "", "",false,false); parameters.push_back(pinputdir);
@@ -190,13 +190,9 @@ GetGroupsCommand::GetGroupsCommand(string option)  {
 			else { m->setNameFile(namefile); }
 			
 			groupfile = validParameter.validFile(parameters, "group", true);
-			if (groupfile == "not open") { abort = true; }
-			else if (groupfile == "not found") {  
-				//if there is a current group file, use it
-				groupfile = m->getGroupFile(); 
-				if (groupfile != "") { m->mothurOut("Using " + groupfile + " as input file for the group parameter."); m->mothurOutEndLine(); }
-				else { 	m->mothurOut("You have no current groupfile and the group parameter is required."); m->mothurOutEndLine(); abort = true; }
-			}else { m->setGroupFile(groupfile); }	
+			if (groupfile == "not open") { groupfile = ""; abort = true; }
+			else if (groupfile == "not found") {  groupfile = "";			}
+			else { m->setGroupFile(groupfile); }	
 			
 			listfile = validParameter.validFile(parameters, "list", true);
 			if (listfile == "not open") { abort = true; }
@@ -384,6 +380,15 @@ int GetGroupsCommand::readFasta(){
 					
 					currSeq.printSequence(out);
 					selectedCount++;
+				}else{
+					//if you are not in the accnos file check if you are a name that needs to be changed
+					map<string, string>::iterator it = uniqueToRedundant.find(name);
+					if (it != uniqueToRedundant.end()) {
+						wroteSomething = true;
+						currSeq.setName(it->second);
+						currSeq.printSequence(out);
+						selectedCount++;
+					}
 				}
 			}
 			m->gobble(in);
@@ -499,10 +504,26 @@ int GetGroupsCommand::readList(){
 					
 					//if that name is in the .accnos file, add it
 					if (names.count(name) != 0) {  newNames += name + ",";  selectedCount++;  }
+					else{
+						//if you are not in the accnos file check if you are a name that needs to be changed
+						map<string, string>::iterator it = uniqueToRedundant.find(name);
+						if (it != uniqueToRedundant.end()) {
+							newNames += it->second + ",";
+							selectedCount++;
+						}
+					}
 				}
 				
 				//get last name
 				if (names.count(binnames) != 0) {  newNames += binnames + ",";  selectedCount++;  }
+				else{
+					//if you are not in the accnos file check if you are a name that needs to be changed
+					map<string, string>::iterator it = uniqueToRedundant.find(binnames);
+					if (it != uniqueToRedundant.end()) {
+						newNames += it->second + ",";
+						selectedCount++;
+					}
+				}
 				
 				//if there are names in this bin add to new list
 				if (newNames != "") {  
@@ -594,6 +615,7 @@ int GetGroupsCommand::readName(){
 					//you know you have at least one valid second since first column is valid
 					for (int i = 0; i < validSecond.size()-1; i++) {  out << validSecond[i] << ',';  }
 					out << validSecond[validSecond.size()-1] << endl;
+					uniqueToRedundant[firstCol] = validSecond[0];
 				}
 			}
 			
@@ -687,6 +709,13 @@ int GetGroupsCommand::readTax(){
 			if (names.count(name) != 0) {
 				wroteSomething = true;
 				out << name << '\t' << tax << endl;
+			}else{
+				//if you are not in the accnos file check if you are a name that needs to be changed
+				map<string, string>::iterator it = uniqueToRedundant.find(name);
+				if (it != uniqueToRedundant.end()) {
+					wroteSomething = true;
+					out << it->second << '\t' << tax << endl;
+				}
 			}
 			
 			m->gobble(in);
