@@ -26,6 +26,9 @@ public:
 	string getCommandName()			{ return "get.relabund";			}
 	string getCommandCategory()		{ return "OTU-Based Approaches";	}
 	string getHelpString();	
+	string getCitation() { return "http://www.mothur.org/wiki/Get.relabund"; }
+	string getDescription()		{ return "calculates the relative abundance of each OTU in a sample"; }
+
 	
 	int execute(); 
 	void help() { m->mothurOut(getHelpString()); }	
