@@ -25,7 +25,8 @@ vector<string> GetSeqsCommand::setParameters(){
 		CommandParameter pdups("dups", "Boolean", "", "T", "", "", "",false,false); parameters.push_back(pdups);
 		CommandParameter pinputdir("inputdir", "String", "", "", "", "", "",false,false); parameters.push_back(pinputdir);
 		CommandParameter poutputdir("outputdir", "String", "", "", "", "", "",false,false); parameters.push_back(poutputdir);
-		
+		CommandParameter paccnos2("accnos2", "InputTypes", "", "", "none", "none", "none",false,true); parameters.push_back(paccnos2);
+
 		vector<string> myArray;
 		for (int i = 0; i < parameters.size(); i++) {	myArray.push_back(parameters[i].name);		}
 		return myArray;
@@ -81,6 +82,7 @@ GetSeqsCommand::GetSeqsCommand(string option)  {
 				
 		//allow user to run help
 		if(option == "help") { help(); abort = true; calledHelp = true; }
+		else if(option == "citation") { citation(); abort = true; calledHelp = true;}
 		
 		else {
 			vector<string> myArray = setParameters();
@@ -199,21 +201,24 @@ GetSeqsCommand::GetSeqsCommand(string option)  {
 					m->mothurOut("You have no valid accnos file and accnos is required."); m->mothurOutEndLine(); 
 					abort = true;
 				} 
-			}	
+			}else { m->setAccnosFile(accnosfile); }	
 			
 			if (accnosfile2 == "not found") { accnosfile2 = ""; }
 			
 			fastafile = validParameter.validFile(parameters, "fasta", true);
 			if (fastafile == "not open") { abort = true; }
-			else if (fastafile == "not found") {  fastafile = "";  }	
+			else if (fastafile == "not found") {  fastafile = "";  }
+			else { m->setFastaFile(fastafile); }
 			
 			namefile = validParameter.validFile(parameters, "name", true);
 			if (namefile == "not open") { abort = true; }
 			else if (namefile == "not found") {  namefile = "";  }	
+			else { m->setNameFile(namefile); }
 			
 			groupfile = validParameter.validFile(parameters, "group", true);
 			if (groupfile == "not open") { abort = true; }
 			else if (groupfile == "not found") {  groupfile = "";  }	
+			else { m->setGroupFile(groupfile); }
 			
 			alignfile = validParameter.validFile(parameters, "alignreport", true);
 			if (alignfile == "not open") { abort = true; }
@@ -222,14 +227,22 @@ GetSeqsCommand::GetSeqsCommand(string option)  {
 			listfile = validParameter.validFile(parameters, "list", true);
 			if (listfile == "not open") { abort = true; }
 			else if (listfile == "not found") {  listfile = "";  }
+			else { m->setListFile(listfile); }
 			
 			taxfile = validParameter.validFile(parameters, "taxonomy", true);
 			if (taxfile == "not open") { abort = true; }
 			else if (taxfile == "not found") {  taxfile = "";  }
+			else { m->setTaxonomyFile(taxfile); }
 			
 			qualfile = validParameter.validFile(parameters, "qfile", true);
 			if (qualfile == "not open") { abort = true; }
 			else if (qualfile == "not found") {  qualfile = "";  }
+			else { m->setQualFile(qualfile); }
+			
+			accnosfile2 = validParameter.validFile(parameters, "accnos2", true);
+			if (accnosfile2 == "not open") { abort = true; }
+			else if (accnosfile2 == "not found") {  accnosfile2 = "";  }
+			
 			
 			string usedDups = "true";
 			string temp = validParameter.validFile(parameters, "dups", false);	if (temp == "not found") { temp = "true"; usedDups = ""; }
@@ -266,9 +279,8 @@ int GetSeqsCommand::execute(){
 		if (qualfile != "")			{		readQual();			}
 		if (accnosfile2 != "")		{		compareAccnos();	}
 		
-		if (m->control_pressed) { outputTypes.clear(); for (int i = 0; i < outputNames.size(); i++) {	remove(outputNames[i].c_str());  } return 0; }
+		if (m->control_pressed) { outputTypes.clear(); for (int i = 0; i < outputNames.size(); i++) {	m->mothurRemove(outputNames[i]);  } return 0; }
 		
-		m->mothurOut("Selected " + toString(names.size()) + " sequences."); m->mothurOutEndLine();
 		
 		if (outputNames.size() != 0) {
 			m->mothurOutEndLine();
@@ -334,10 +346,11 @@ int GetSeqsCommand::readFasta(){
 		string name;
 		
 		bool wroteSomething = false;
+		int selectedCount = 0;
 		
 		while(!in.eof()){
 		
-			if (m->control_pressed) { in.close(); out.close(); remove(outputFileName.c_str());  return 0; }
+			if (m->control_pressed) { in.close(); out.close(); m->mothurRemove(outputFileName);  return 0; }
 			
 			Sequence currSeq(in);
 			name = currSeq.getName();
@@ -348,6 +361,7 @@ int GetSeqsCommand::readFasta(){
 					wroteSomething = true;
 					
 					currSeq.printSequence(out);
+					selectedCount++;
 				}
 			}
 			m->gobble(in);
@@ -359,6 +373,8 @@ int GetSeqsCommand::readFasta(){
 		if (wroteSomething == false) { m->mothurOut("Your file does not contain any sequence from the .accnos file."); m->mothurOutEndLine();  }
 		outputNames.push_back(outputFileName);  outputTypes["fasta"].push_back(outputFileName); 
 		
+		m->mothurOut("Selected " + toString(selectedCount) + " sequences from your fasta file."); m->mothurOutEndLine();
+		
 		return 0;
 
 	}
@@ -382,6 +398,7 @@ int GetSeqsCommand::readQual(){
 		string name;
 		
 		bool wroteSomething = false;
+		int selectedCount = 0;
 		
 		
 		while(!in.eof()){	
@@ -413,6 +430,7 @@ int GetSeqsCommand::readQual(){
 				wroteSomething = true;
 						
 				out << name << endl << scores;
+				selectedCount++;
 			}
 			
 			m->gobble(in);
@@ -424,6 +442,9 @@ int GetSeqsCommand::readQual(){
 		if (wroteSomething == false) { m->mothurOut("Your file does not contain any sequence from the .accnos file."); m->mothurOutEndLine();  }
 		outputNames.push_back(outputFileName);  outputTypes["qfile"].push_back(outputFileName); 
 		
+		m->mothurOut("Selected " + toString(selectedCount) + " sequences from your quality file."); m->mothurOutEndLine();
+
+		
 		return 0;
 		
 	}
@@ -445,10 +466,13 @@ int GetSeqsCommand::readList(){
 		m->openInputFile(listfile, in);
 		
 		bool wroteSomething = false;
+		int selectedCount = 0;
 		
 		while(!in.eof()){
 			
-			if (m->control_pressed) { in.close(); out.close(); remove(outputFileName.c_str());  return 0; }
+			selectedCount = 0;
+			
+			if (m->control_pressed) { in.close(); out.close(); m->mothurRemove(outputFileName);  return 0; }
 
 			//read in list vector
 			ListVector list(in);
@@ -469,11 +493,11 @@ int GetSeqsCommand::readList(){
 					binnames = binnames.substr(binnames.find_first_of(',')+1, binnames.length());
 					
 					//if that name is in the .accnos file, add it
-					if (names.count(name) != 0) {  newNames += name + ",";  }
+					if (names.count(name) != 0) {  newNames += name + ",";  selectedCount++; }
 				}
 			
 				//get last name
-				if (names.count(binnames) != 0) {  newNames += binnames + ",";  }
+				if (names.count(binnames) != 0) {  newNames += binnames + ",";  selectedCount++; }
 
 				//if there are names in this bin add to new list
 				if (newNames != "") { 
@@ -496,6 +520,8 @@ int GetSeqsCommand::readList(){
 		if (wroteSomething == false) { m->mothurOut("Your file does not contain any sequence from the .accnos file."); m->mothurOutEndLine();  }
 		outputNames.push_back(outputFileName); outputTypes["list"].push_back(outputFileName);
 		
+		m->mothurOut("Selected " + toString(selectedCount) + " sequences from your list file."); m->mothurOutEndLine();
+		
 		return 0;
 
 	}
@@ -519,11 +545,11 @@ int GetSeqsCommand::readName(){
 		string name, firstCol, secondCol;
 		
 		bool wroteSomething = false;
-		
+		int selectedCount = 0;
 		
 		while(!in.eof()){
 		
-			if (m->control_pressed) { in.close(); out.close(); remove(outputFileName.c_str());  return 0; }
+			if (m->control_pressed) { in.close(); out.close(); m->mothurRemove(outputFileName);  return 0; }
 
 			in >> firstCol;				
 			in >> secondCol;
@@ -545,7 +571,10 @@ int GetSeqsCommand::readName(){
 				for (int i = 0; i < parsedNames.size(); i++) {  names.insert(parsedNames[i]);  }
 				out << firstCol << '\t' << hold << endl;
 				wroteSomething = true;
+				selectedCount += parsedNames.size();
 			}else {
+				selectedCount += validSecond.size();
+				
 				//if the name in the first column is in the set then print it and any other names in second column also in set
 				if (names.count(firstCol) != 0) {
 				
@@ -581,6 +610,8 @@ int GetSeqsCommand::readName(){
 		if (wroteSomething == false) { m->mothurOut("Your file does not contain any sequence from the .accnos file."); m->mothurOutEndLine();  }
 		outputNames.push_back(outputFileName); outputTypes["name"].push_back(outputFileName);
 		
+		m->mothurOut("Selected " + toString(selectedCount) + " sequences from your name file."); m->mothurOutEndLine();
+		
 		return 0;
 		
 	}
@@ -605,10 +636,11 @@ int GetSeqsCommand::readGroup(){
 		string name, group;
 		
 		bool wroteSomething = false;
+		int selectedCount = 0;
 		
 		while(!in.eof()){
 
-			if (m->control_pressed) { in.close(); out.close(); remove(outputFileName.c_str());  return 0; }
+			if (m->control_pressed) { in.close(); out.close(); m->mothurRemove(outputFileName);  return 0; }
 
 
 			in >> name;				//read from first column
@@ -619,6 +651,7 @@ int GetSeqsCommand::readGroup(){
 				wroteSomething = true;
 				
 				out << name << '\t' << group << endl;
+				selectedCount++;
 			}
 					
 			m->gobble(in);
@@ -629,6 +662,9 @@ int GetSeqsCommand::readGroup(){
 		if (wroteSomething == false) { m->mothurOut("Your file does not contain any sequence from the .accnos file."); m->mothurOutEndLine();  }
 		outputNames.push_back(outputFileName);  outputTypes["group"].push_back(outputFileName);
 		
+		m->mothurOut("Selected " + toString(selectedCount) + " sequences from your group file."); m->mothurOutEndLine();
+
+		
 		return 0;
 
 	}
@@ -651,10 +687,11 @@ int GetSeqsCommand::readTax(){
 		string name, tax;
 		
 		bool wroteSomething = false;
+		int selectedCount = 0;
 		
 		while(!in.eof()){
 
-			if (m->control_pressed) { in.close(); out.close(); remove(outputFileName.c_str());  return 0; }
+			if (m->control_pressed) { in.close(); out.close(); m->mothurRemove(outputFileName);  return 0; }
 
 			in >> name;				//read from first column
 			in >> tax;			//read from second column
@@ -664,6 +701,7 @@ int GetSeqsCommand::readTax(){
 				wroteSomething = true;
 				
 				out << name << '\t' << tax << endl;
+				selectedCount++;
 			}
 					
 			m->gobble(in);
@@ -673,6 +711,8 @@ int GetSeqsCommand::readTax(){
 		
 		if (wroteSomething == false) { m->mothurOut("Your file does not contain any sequence from the .accnos file."); m->mothurOutEndLine();  }
 		outputNames.push_back(outputFileName);  outputTypes["taxonomy"].push_back(outputFileName);
+		
+		m->mothurOut("Selected " + toString(selectedCount) + " sequences from your taxonomy file."); m->mothurOutEndLine();
 			
 		return 0;
 
@@ -698,6 +738,7 @@ int GetSeqsCommand::readAlign(){
 		string name, junk;
 		
 		bool wroteSomething = false;
+		int selectedCount = 0;
 		
 		//read column headers
 		for (int i = 0; i < 16; i++) {  
@@ -708,7 +749,7 @@ int GetSeqsCommand::readAlign(){
 		
 		while(!in.eof()){
 		
-			if (m->control_pressed) { in.close(); out.close(); remove(outputFileName.c_str());  return 0; }
+			if (m->control_pressed) { in.close(); out.close(); m->mothurRemove(outputFileName);  return 0; }
 
 
 			in >> name;				//read from first column
@@ -716,6 +757,7 @@ int GetSeqsCommand::readAlign(){
 			//if this name is in the accnos file
 			if (names.count(name) != 0) {
 				wroteSomething = true;
+				selectedCount++;
 				
 				out << name << '\t';
 				
@@ -742,6 +784,8 @@ int GetSeqsCommand::readAlign(){
 		if (wroteSomething == false) { m->mothurOut("Your file does not contain any sequence from the .accnos file."); m->mothurOutEndLine();  }
 		outputNames.push_back(outputFileName);  outputTypes["alignreport"].push_back(outputFileName);
 		
+		m->mothurOut("Selected " + toString(selectedCount) + " sequences from your alignreport file."); m->mothurOutEndLine();
+		
 		return 0;
 		
 	}
@@ -823,7 +867,15 @@ int GetSeqsCommand::compareAccnos(){
 			in >> name;
 			
 			if (namesAccnos.count(name) == 0){ //name unique to accnos2
-				namesAccnos2.insert(name);
+				int pos = name.find_last_of('_');
+				string tempName = name;
+				if (pos != string::npos) {  tempName = tempName.substr(pos+1); cout << tempName << endl; }
+				if (namesAccnos.count(tempName) == 0){
+					namesAccnos2.insert(name);
+				}else { //you are in both so erase
+					namesAccnos.erase(name);
+					namesDups.insert(name);
+				}
 			}else { //you are in both so erase
 				namesAccnos.erase(name);
 				namesDups.insert(name);
