@@ -178,14 +178,14 @@ MetaStatsCommand::MetaStatsCommand(string option) {
 
 			
 			string temp = validParameter.validFile(parameters, "iters", false);			if (temp == "not found") { temp = "1000"; }
-			convert(temp, iters); 
+			m->mothurConvert(temp, iters); 
 			
 			temp = validParameter.validFile(parameters, "threshold", false);			if (temp == "not found") { temp = "0.05"; }
-			convert(temp, threshold); 
+			m->mothurConvert(temp, threshold); 
 			
 			temp = validParameter.validFile(parameters, "processors", false);	if (temp == "not found"){	temp = m->getProcessors();	}
 			m->setProcessors(temp);
-			convert(temp, processors);
+			m->mothurConvert(temp, processors);
 		}
 
 	}
@@ -394,7 +394,7 @@ int MetaStatsCommand::driver(int start, int num, vector<SharedRAbundVector*>& th
 			//get set names
 			string setA = namesOfGroupCombos[c][0]; 
 			string setB = namesOfGroupCombos[c][1];
-		
+		//cout << setA << '\t' << setB << endl;
 			//get filename
 			string outputFileName = outputDir +  m->getRootName(m->getSimpleName(sharedfile)) + thisLookUp[0]->getLabel() + "." + setA + "-" + setB + ".metastats";
 			outputNames.push_back(outputFileName); outputTypes["metastats"].push_back(outputFileName);
@@ -425,7 +425,8 @@ int MetaStatsCommand::driver(int start, int num, vector<SharedRAbundVector*>& th
 				}
 			}
 			
-			//for (int i = 0; i < subset.size(); i++) { cout << subset[i]->getGroup() << endl; }
+			//for (int i = 0; i < subset.size(); i++) { cout << designMap->getGroup(subset[i]->getGroup()) << endl; }
+			//cout << setACount << endl;
 			
 			if ((setACount == 0) || (setBCount == 0))  { 
 				m->mothurOut("Missing shared info for " + setA + " or " + setB + ". Skipping comparison."); m->mothurOutEndLine(); 
