@@ -53,7 +53,7 @@ class MothurOut {
 		vector<string> binLabelsInFile;
 		vector<string> currentBinLabels;
 		string saveNextLabel, argv, sharedHeaderMode;
-		bool printedHeaders;
+		bool printedHeaders, commandInputsConvertError;
 		
 		//functions from mothur.h
 		//file operations
@@ -83,7 +83,11 @@ class MothurOut {
 		int readNames(string, map<string, string>&);
 		int readNames(string, map<string, vector<string> >&);
 		int readNames(string, vector<seqPriorityNode>&, map<string, string>&);
-		void mothurRemove(string);
+		int mothurRemove(string);
+		bool mothurConvert(string, int&); //use for converting user inputs. Sets commandInputsConvertError to true if error occurs. Engines check this.
+		bool mothurConvert(string, float&); //use for converting user inputs. Sets commandInputsConvertError to true if error occurs. Engines check this.
+		bool mothurConvert(string, double&); //use for converting user inputs. Sets commandInputsConvertError to true if error occurs. Engines check this.
+	
 		
 		//searchs and checks
 		bool checkReleaseVersion(ifstream&, string);
@@ -93,8 +97,10 @@ class MothurOut {
 		void getNumSeqs(ifstream&, int&);
 		int getNumSeqs(ifstream&);
 		int getNumNames(string);
+		int getNumChar(string, char);
 		bool isTrue(string);
 		bool isContainingOnlyDigits(string);
+		bool isNumeric1(string);
 	
 		
 		//string manipulation
@@ -105,6 +111,7 @@ class MothurOut {
 		void splitAtDash(string&, set<string>&);
 		void splitAtDash(string&, vector<string>&);
 		void splitAtChar(string&, vector<string>&, char);
+		int removeConfidences(string&);
 		
 		//math operation
 		int factorial(int num);
@@ -195,6 +202,7 @@ class MothurOut {
 			flowfile = "";
 			gui = false;
 			printedHeaders = false;
+			commandInputsConvertError = false;
 			sharedHeaderMode = "";
 		}
 		~MothurOut();
