@@ -24,6 +24,9 @@ public:
 	string getCommandName()			{ return "parse.fastq";		}
 	string getCommandCategory()		{ return "Sequence Processing"; }
 	string getHelpString();	
+	string getCitation() { return "http://www.mothur.org/wiki/Parse.fastq"; }
+	string getDescription()		{ return "reads a fastq file and creates a fasta and quality file"; }
+
 	
 	int execute(); 
 	void help() { m->mothurOut(getHelpString()); }		
