@@ -171,11 +171,11 @@ ParsimonyCommand::ParsimonyCommand(string option)  {
 			}
 				
 			itersString = validParameter.validFile(parameters, "iters", false);			if (itersString == "not found") { itersString = "1000"; }
-			convert(itersString, iters); 
+			m->mothurConvert(itersString, iters); 
 			
 			string temp = validParameter.validFile(parameters, "processors", false);	if (temp == "not found"){	temp = m->getProcessors();	}
 			m->setProcessors(temp);
-			convert(temp, processors);
+			m->mothurConvert(temp, processors);
 			
 		}
 
