@@ -241,6 +241,8 @@ int PhyloTree::addSeqToTree(string seqName, string seqTaxonomy){
 		int level = 1;
 		
 		tree[0].accessions.push_back(seqName);
+		m->removeConfidences(seqTaxonomy);
+		
 		string taxon;// = getNextTaxon(seqTaxonomy);
 	
 		while(seqTaxonomy != ""){
@@ -618,9 +620,10 @@ bool PhyloTree::ErrorCheck(vector<string> templateFileNames){
 				okay = false;
 			}
 			
-			templateFileNames.erase(templateFileNames.begin()+i);
-			i--;
+			//templateFileNames.erase(templateFileNames.begin()+i);
+			//i--;
 		}
+		templateFileNames.clear();
 		
 		if (taxonomyFileNames.size() > 0) { //there are names in tax file that are not in template
 			okay = false;
