@@ -22,6 +22,9 @@ public:
 	string getCommandName()			{ return "reverse.seqs";			}
 	string getCommandCategory()		{ return "Sequence Processing";		}
 	string getHelpString();	
+	string getCitation() { return "http://www.mothur.org/wiki/Reverse.seqs"; }
+	string getDescription()		{ return "outputs a fasta file containing the reverse-complements"; }
+
 	
 	int execute(); 
 	void help() { m->mothurOut(getHelpString()); }	
