@@ -24,7 +24,9 @@ public:
 	string getCommandName()			{ return "set.current";	}
 	string getCommandCategory()		{ return "General";		}
 	string getHelpString();	
-	
+	string getCitation() { return "http://www.mothur.org/wiki/Set.current"; }
+	string getDescription()		{ return "set current files for mothur"; }
+
 	int execute(); 
 	void help() { m->mothurOut(getHelpString()); }	
 	
@@ -37,7 +39,7 @@ private:
 	vector<string> types;
 	
 	string accnosfile, phylipfile, columnfile, listfile, rabundfile, sabundfile, namefile, groupfile, designfile, taxonomyfile;
-	string orderfile, treefile, sharedfile, ordergroupfile, relabundfile, fastafile, qualfile, sfffile, oligosfile;
+	string orderfile, treefile, sharedfile, ordergroupfile, relabundfile, fastafile, qualfile, sfffile, oligosfile, processors, flowfile;
 
 	
 };
