@@ -33,7 +33,7 @@ EstOutput KulczynskiCody::getValues(vector<SharedRAbundVector*> shared) {
 			if ((tempA != 0) && (tempB != 0)) {	S12++; }
 		}
 		
-		data[0] = 0.5 * ((S12 / (float)S1) + (S12 / (float)S2));
+		data[0] = 1.0 - 0.5 * ((S12 / (float)S1) + (S12 / (float)S2));
 		
 		if (isnan(data[0]) || isinf(data[0])) { data[0] = 0; }
 		
