@@ -23,7 +23,7 @@ vector<string> ShhherCommand::setParameters(){
 	try {
 		CommandParameter pflow("flow", "InputTypes", "", "", "none", "fileflow", "none",false,false); parameters.push_back(pflow);
 		CommandParameter pfile("file", "InputTypes", "", "", "none", "fileflow", "none",false,false); parameters.push_back(pfile);
-		CommandParameter plookup("lookup", "InputTypes", "", "", "none", "none", "none",false,true); parameters.push_back(plookup);
+		CommandParameter plookup("lookup", "InputTypes", "", "", "none", "none", "none",false,false); parameters.push_back(plookup);
 		CommandParameter pcutoff("cutoff", "Number", "", "0.01", "", "", "",false,false); parameters.push_back(pcutoff);
 		CommandParameter pprocessors("processors", "Number", "", "1", "", "", "",false,false); parameters.push_back(pprocessors);
 		CommandParameter pmaxiter("maxiter", "Number", "", "1000", "", "", "",false,false); parameters.push_back(pmaxiter);
@@ -251,19 +251,19 @@ ShhherCommand::ShhherCommand(string option) {
 			
 			temp = validParameter.validFile(parameters, "processors", false);	if (temp == "not found"){	temp = m->getProcessors();	}
 			m->setProcessors(temp);
-			convert(temp, processors);
+			m->mothurConvert(temp, processors);
 
 			temp = validParameter.validFile(parameters, "cutoff", false);	if (temp == "not found"){	temp = "0.01";		}
-			convert(temp, cutoff); 
+			m->mothurConvert(temp, cutoff); 
 			
 			temp = validParameter.validFile(parameters, "mindelta", false);	if (temp == "not found"){	temp = "0.000001";	}
-			convert(temp, minDelta); 
+			m->mothurConvert(temp, minDelta); 
 
 			temp = validParameter.validFile(parameters, "maxiter", false);	if (temp == "not found"){	temp = "1000";		}
-			convert(temp, maxIters); 
+			m->mothurConvert(temp, maxIters); 
 
 			temp = validParameter.validFile(parameters, "sigma", false);if (temp == "not found")	{	temp = "60";		}
-			convert(temp, sigma); 
+			m->mothurConvert(temp, sigma); 
 			
 			flowOrder = validParameter.validFile(parameters, "order", false);
 			if (flowOrder == "not found"){ flowOrder = "TACG";		}
@@ -1501,9 +1501,8 @@ void ShhherCommand::getOTUData(string listFileName){
 
 void ShhherCommand::initPyroCluster(){                          
 	try{
-		
 		if (numOTUs < processors) { processors = 1; }
-		
+
 		dist.assign(numSeqs * numOTUs, 0);
 		change.assign(numOTUs, 1);
 		centroids.assign(numOTUs, -1);
@@ -2151,7 +2150,9 @@ void ShhherCommand::setOTUs(){
 void ShhherCommand::writeQualities(vector<int> otuCounts){
 	
 	try {
-		string qualityFileName = flowFileName.substr(0,flowFileName.find_last_of('.')) + ".shhh.qual";
+		string thisOutputDir = outputDir;
+		if (outputDir == "") {  thisOutputDir += m->hasPath(flowFileName);  }
+		string qualityFileName = thisOutputDir + m->getRootName(m->getSimpleName(flowFileName)) + ".shhh.qual";
 
 		ofstream qualityFile;
 		m->openOutputFile(qualityFileName, qualityFile);
@@ -2256,8 +2257,9 @@ void ShhherCommand::writeQualities(vector<int> otuCounts){
 
 void ShhherCommand::writeSequences(vector<int> otuCounts){
 	try {
-		
-		string fastaFileName = flowFileName.substr(0,flowFileName.find_last_of('.')) + ".shhh.fasta";
+		string thisOutputDir = outputDir;
+		if (outputDir == "") {  thisOutputDir += m->hasPath(flowFileName);  }
+		string fastaFileName = thisOutputDir + m->getRootName(m->getSimpleName(flowFileName)) + ".shhh.fasta";
 		ofstream fastaFile;
 		m->openOutputFile(fastaFileName, fastaFile);
 		
@@ -2303,7 +2305,9 @@ void ShhherCommand::writeSequences(vector<int> otuCounts){
 
 void ShhherCommand::writeNames(vector<int> otuCounts){
 	try {
-		string nameFileName = flowFileName.substr(0,flowFileName.find_last_of('.')) + ".shhh.names";
+		string thisOutputDir = outputDir;
+		if (outputDir == "") {  thisOutputDir += m->hasPath(flowFileName);  }
+		string nameFileName = thisOutputDir + m->getRootName(m->getSimpleName(flowFileName)) + ".shhh.names";
 		ofstream nameFile;
 		m->openOutputFile(nameFileName, nameFile);
 		
@@ -2339,7 +2343,9 @@ void ShhherCommand::writeNames(vector<int> otuCounts){
 
 void ShhherCommand::writeGroups(){
 	try {
-		string fileRoot = flowFileName.substr(0,flowFileName.find_last_of('.'));
+		string thisOutputDir = outputDir;
+		if (outputDir == "") {  thisOutputDir += m->hasPath(flowFileName);  }
+		string fileRoot = thisOutputDir + m->getRootName(m->getSimpleName(flowFileName));
 		string groupFileName = fileRoot + ".shhh.groups";
 		ofstream groupFile;
 		m->openOutputFile(groupFileName, groupFile);
@@ -2362,7 +2368,9 @@ void ShhherCommand::writeGroups(){
 
 void ShhherCommand::writeClusters(vector<int> otuCounts){
 	try {
-		string otuCountsFileName = flowFileName.substr(0,flowFileName.find_last_of('.')) + ".shhh.counts";
+		string thisOutputDir = outputDir;
+		if (outputDir == "") {  thisOutputDir += m->hasPath(flowFileName);  }
+		string otuCountsFileName = thisOutputDir + m->getRootName(m->getSimpleName(flowFileName)) + ".shhh.counts";
 		ofstream otuCountsFile;
 		m->openOutputFile(otuCountsFileName, otuCountsFile);
 		
