@@ -129,7 +129,7 @@ private:
 //custom data structure for threads to use.
 // This is passed by void pointer so it can be any data type
 // that can be passed using a single void pointer (LPVOID).
-typedef struct flowDistParentForkData {
+struct flowDistParentForkData {
 	string distFileName; 
 	vector<int> mapUniqueToSeq;
 	vector<int> mapSeqToUnique;
