@@ -203,8 +203,8 @@ TrimSeqsCommand::TrimSeqsCommand(string option)  {
 			// ...at some point should added some additional type checking...
 			string temp;
 			temp = validParameter.validFile(parameters, "flip", false);
-			if (temp == "not found"){	flip = 0;	}
-			else if(m->isTrue(temp))	{	flip = 1;	}
+			if (temp == "not found")    {	flip = 0;	}
+			else {  flip = m->isTrue(temp);		}
 		
 			temp = validParameter.validFile(parameters, "oligos", true);
 			if (temp == "not found"){	oligoFile = "";		}
@@ -213,25 +213,25 @@ TrimSeqsCommand::TrimSeqsCommand(string option)  {
 			
 			
 			temp = validParameter.validFile(parameters, "maxambig", false);		if (temp == "not found") { temp = "-1"; }
-			convert(temp, maxAmbig);  
+			m->mothurConvert(temp, maxAmbig);  
 
 			temp = validParameter.validFile(parameters, "maxhomop", false);		if (temp == "not found") { temp = "0"; }
-			convert(temp, maxHomoP);  
+			m->mothurConvert(temp, maxHomoP);  
 
 			temp = validParameter.validFile(parameters, "minlength", false);	if (temp == "not found") { temp = "0"; }
-			convert(temp, minLength); 
+			m->mothurConvert(temp, minLength); 
 			
 			temp = validParameter.validFile(parameters, "maxlength", false);	if (temp == "not found") { temp = "0"; }
-			convert(temp, maxLength);
+			m->mothurConvert(temp, maxLength);
 			
 			temp = validParameter.validFile(parameters, "bdiffs", false);		if (temp == "not found") { temp = "0"; }
-			convert(temp, bdiffs);
+			m->mothurConvert(temp, bdiffs);
 			
 			temp = validParameter.validFile(parameters, "pdiffs", false);		if (temp == "not found") { temp = "0"; }
-			convert(temp, pdiffs);
+			m->mothurConvert(temp, pdiffs);
 			
 			temp = validParameter.validFile(parameters, "tdiffs", false);		if (temp == "not found") { int tempTotal = pdiffs + bdiffs;  temp = toString(tempTotal); }
-			convert(temp, tdiffs);
+			m->mothurConvert(temp, tdiffs);
 			
 			if(tdiffs == 0){	tdiffs = bdiffs + pdiffs;	}
 			
@@ -246,7 +246,7 @@ TrimSeqsCommand::TrimSeqsCommand(string option)  {
 			else						{	nameFile = temp;	m->setNameFile(nameFile); }
 			
 			temp = validParameter.validFile(parameters, "qthreshold", false);	if (temp == "not found") { temp = "0"; }
-			convert(temp, qThreshold);
+			m->mothurConvert(temp, qThreshold);
 			
 			temp = validParameter.validFile(parameters, "qtrim", false);		if (temp == "not found") { temp = "t"; }
 			qtrim = m->isTrue(temp);
@@ -277,7 +277,7 @@ TrimSeqsCommand::TrimSeqsCommand(string option)  {
 			
 			temp = validParameter.validFile(parameters, "processors", false);	if (temp == "not found"){	temp = m->getProcessors();	}
 			m->setProcessors(temp);
-			convert(temp, processors); 
+			m->mothurConvert(temp, processors); 
 			
 			
 			if(allFiles && (oligoFile == "")){
@@ -1019,33 +1019,7 @@ int TrimSeqsCommand::setLines(string filename, string qfilename, vector<unsigned
 		#else
 		
 			fastaFilePos.push_back(0); qfileFilePos.push_back(0);
-			//get last file position of fastafile
-			FILE * pFile;
-			unsigned long long size;
-			
-			//get num bytes in file
-			pFile = fopen (filename.c_str(),"rb");
-			if (pFile==NULL) perror ("Error opening file");
-			else{
-				fseek (pFile, 0, SEEK_END);
-				size=ftell (pFile);
-				fclose (pFile);
-			}
-			fastaFilePos.push_back(size);
-			
-			//get last file position of fastafile
-			FILE * qFile;
-			
-			//get num bytes in file
-			qFile = fopen (qfilename.c_str(),"rb");
-			if (qFile==NULL) perror ("Error opening file");
-			else{
-				fseek (qFile, 0, SEEK_END);
-				size=ftell (qFile);
-				fclose (qFile);
-			}
-			qfileFilePos.push_back(size);
-		
+			fastaFilePos.push_back(1000); qfileFilePos.push_back(1000);
 			return 1;
 		
 		#endif
